::  CAM2 M10, Q and Gage System Information Retrieval Tool
::  This tool retreives CAM2 Log Files and System Configuration (.nfo file)
::  To be used by FARO Customer Support in troubleshooting

::  This tool is compatabile with:
::  Windows XP, Windows Vista and Windows 7
::  CAM2 Q, CAM2 M10 and CAM2 Gage

::  Version 1.0 - Feb 20, 2012



@echo off


::Set a TEMPDIR as a folder named FARO_TEMP to the users TEMP folder
set TEMPDIR="%TEMP%\FARO_TEMP"


::  Make the temporary directory.  Remove the temp directory if one already exists from another run of this tool
rmdir %TEMPDIR% /S /Q
mkdir %TEMPDIR%



::***********************Check Windows Version*******************************

::  Windows XP
ver | findstr /i "5\.1\." > nul
IF %ERRORLEVEL% EQU 0 goto ver_XP

ver | findstr /i "6\.0\." > nul
IF %ERRORLEVEL% EQU 0 goto ver_Win7_Vista

ver | findstr /i "6\.1\." > nul
IF %ERRORLEVEL% EQU 0 goto ver_Win7_Vista


::******************************Windows XP************************************

:ver_XP

echo *************************************************
echo **     Windows XP Operating System Detected    **
echo **    Obtaining CAM2 M10 and CAM2 Q Log Files  **
echo *************************************************



:: Define FILETOMOVE as the CAM2Q log file folder
set FILETOMOVE="%USERPROFILE%\Local Settings\Application Data\FARO Technologies"

::Copy CAM2Q log file folder to TEMPDIR
xcopy %FILETOMOVE% %TEMPDIR% /e


::Define FILETOMOVE as the CAM2 Measure 10 log file folder
set FILETOMOVE="%USERPROFILE%\Application Data\CAM2 Measure\10.0\Logs"

::Create a new folder called Measure 10 in the TEMPDIR
::Copy CAM2 M10 log file folder to this new folder

Set M10DIR="%TEMP%\FARO_TEMP\Measure 10"
mkdir %M10DIR%
xcopy %FILETOMOVE% %M10DIR% /e


goto nfo_file

::*************************End Windows XP**************************************


::******************************Windows 7 or Vista***********************************

:ver_Win7_Vista

echo *************************************************
echo ** Windows 7 / Vista Operating System Detected **
echo **   Obtaining CAM2 M10 and CAM2 Q Log Files   **
echo *************************************************


:: Define FILETOMOVE as the CAM2Q log file folder
set FILETOMOVE="%USERPROFILE%\AppData\Local\FARO Technologies"

::Copy CAM2Q log file folder to TEMPDIR
xcopy %FILETOMOVE% %TEMPDIR% /e


::Define FILETOMOVE as the CAM2 Measure 10 log file folder
set FILETOMOVE="%USERPROFILE%\AppData\Roaming\CAM2 Measure\10.0\Logs"

::Create a new folder called Measure 10 in the TEMPDIR
::Copy CAM2 M10 log file folder to this new folder

Set M10DIR="%TEMP%\FARO_TEMP\Measure 10"
mkdir %M10DIR%
xcopy %FILETOMOVE% %M10DIR% /e

goto nfo_file

::*************************End Windows 7 or Vista*****************************************



::**************************************Create .nfo file********************************

:nfo_file

::clear the screen and display new heading

cls
echo *************************************************
echo **        Obtaining System Configuration       **
echo **                                             **
echo **       This may take several minutes         **
echo **              Please be patient              **
echo *************************************************


:: Change folder to location of MSInfo program
:: The location of this program is the identical for both Win XP and Win 7

cd C:\Program Files\Common Files\Microsoft Shared\MSInfo\

::Set NFOLOCATION as a file named computer.nfo on in the temp directory on the desktop
::Create .nfo file

set NFOLOCATION="%TEMP%\FARO_TEMP\computer.nfo"

msinfo32.exe /nfo %NFOLOCATION%



::***********************************Compress all Information*************************


::Create a windows script file named _zipIt.vbs that compresses an entire folder
::First, change the DOS working directory to the temp directory so this script is written
::their.  If not, it would be written to the folder that MSinfo is in
::and this could create a problem if computer has strict write privlidges

::clear the screen and display new heading

cls

echo *************************************************
echo **            Compressing Information          **
echo *************************************************


cd %TEMP%


::  Creation of script file

echo Set objArgs = WScript.Arguments > _zipIt.vbs
echo InputFolder = objArgs(0) >> _zipIt.vbs
echo ZipFile = objArgs(1) >> _zipIt.vbs
echo CreateObject("Scripting.FileSystemObject").CreateTextFile(ZipFile, True).Write "PK" ^& Chr(5) ^& Chr(6) ^& String(18, vbNullChar) >> _zipIt.vbs

echo Set objShell = CreateObject("Shell.Application") >> _zipIt.vbs
echo Set source = objShell.NameSpace(InputFolder).Items >> _zipIt.vbs
echo objShell.NameSpace(ZipFile).CopyHere(source) >> _zipIt.vbs
echo wScript.Sleep 2000 >> _zipIt.vbs


::end of script file creation


::  Run the script file and compress the TEMPDIR creating a file called nfo.zip
::  The nfo.zip file should be placed on the desktop


Set ZIPFILE="%USERPROFILE%\Desktop\CAM2_Support_Data.zip"

CScript  _zipIt.vbs  %TEMPDIR%  %ZIPFILE%



:  Delete all remaining files and the TEMPDIR
del _zipIt.vbs

rmdir %TEMPDIR% /S /Q


::clear the screen and display new heading

cls

echo *************************************************
echo *************************************************
echo **                                             **
echo **   On your Windows Desktop is a file named:  **
echo **                                             **
echo **                                             **
echo **          CAM2_Support_Data.zip              **
echo **                                             **
echo **                                             **
echo **  Please send this file to FARO Support      **
echo **                                             **
echo **                                             **
echo *************************************************
echo *************************************************


Pause

